function [Effectif,Centre] = hncfd(Loi,a,b,X,barcol)
%
% HNCFD :            Histogramme Normalis et Courbes des Fonctions
%    de Densit empirique et thorique associes.
%
% [Effectif,Centre] = hncfd(Loi,a,b,X,,barcol);
%
% Entres :
% ---------
% Loi  : Loi de probabilit. 2 cas possibles :
%          'norm' : loi normale
%          'unif' : loi uniforme
% a, b : paramtres de la loi : 
%          pour la loi normale  : Esprance et cart type
%          pour la loi uniforme : borne inf et sup de l'intervalle
% X    : Matrice des donnes
% barcol : (optionnel), vecteur couleur d'affichage des barres d'histogramme :
%          [r g b] : elles le sont avec ce vecteur couleur
%          0 : les barres ne sont pas affiches
%          1 ou par dfaut, elles le sont (dans une couleur par dfaut)
% 
% Sorties :
% ---------
% Effectif : Nombres d'lments de chaque bar de l'histogramme.
% Centre   : Valeur centrale (position) de chaque bar de l'histogramme.
% Ces 2 sorties sont produites pour garder la compatibilit avec
% la fonction hist

%_________________________________________________________
% Auteur : C.Sorror (octobre 2012)
% --------------------------------------------------------
if (nargin<4)
   error('syntax is : hncfd(Loi,a,b,X,barcol)')
end
coldef = [0.0 0.0 0.5]; %[0.7 1.0 0.7]; %[0.9 0.9 0.75] vecteur de couleur par defaut des barres 
if (nargin==4)
   barcol = coldef;
end
if (nargin==5)
   if (length(barcol)~=3)
      if (barcol==1)
         barcol = coldef;
      else
         barcol = 0; 
      end
   end
end
%
hold on
%
% Hitogramme normalis (si demand (ou par defaut))
if (length(barcol)==3)
   if (max(barcol)>1 | min(barcol)<0)
      barcol = coldef;
      disp('hncfd: bad color bar vecrtor, default used');
   end
   [Effectif,Centre] = hist(X);
   C = diff(Centre); 
   Densite = Effectif/length(X)/C(1);
   h=bar(Centre,Densite);
   set(h,'facecolor',barcol); 
end
%
% Re-calcul moins regroups des densits pour avoir des tracs de 
% courbes plus arrondis
[Effectif,Centre] = hist(X,20);
C = diff(Centre); 
Densite = Effectif/length(X)/C(1);
%
% Calcul de la fonction de densit empirique puis thorique selon la loi
if (Loi=='norm')
   aempir = mean(X); bempir = std(X); 
   dempir = normpdf(Centre,aempir,bempir);  % -> densite empirique
   dtheor = normpdf(Centre,a,b);            % -> densit thorique
elseif (Loi=='unif')
   aempir = min(X); bempir = max(X);
   dempir = unifpdf(Centre,aempir,bempir);  % -> densite empirique
   dtheor = unifpdf(Centre,a,b);            % -> densit thorique
else
   error('hncfd: la Loi doit etre ''norm'' ou ''unif''');
end
%
% then, plot them
hp1=plot(Centre,dempir,'o-g','color',[0  0.5  0],'linewidth',1.5);
hp2=plot(Centre,dtheor,'x-r','linewidth',1);
if (exist('OCTAVE_VERSION'))
   legend('','pdf empirique','pdf thorique');
else
   legend([hp1,hp2],'pdf empirique','pdf thorique');
end
%
% Check sum = 1 : ----------------------------------------
%Densite * [ C' ; C(1)]  % check :Sum densite*dx = 1
%sum(Densite*C(1)) % Ce qui revient au meme
%sum(dempir*C(1))  %~=1.00
%sum(dtheor*C(1))  %~=1.00
% --------------------------------------------------------
%

