function moustache(Data)
%
% MOUSTACHE :      Produit une figure de boite  moustaches pour  
%    chaque colonne de la matrice des donnes Data, passe en 
%    paramtre
%
% moustache(Data);
%
% Entre :
% -------- 
% Data : Matrice de donnes 
%
% description des boites  moustaches produites :
%
%         -----         <--- Valeur Maximum
%           |
%           |
%       ---------       <--- 3me quartile (Q75)
%       |       |
%       |       |
%       |       |
%       |-------|       <--- 2me quartile, valeur mdiane(Q50)
%       |       |
%       |       |
%       ---------       <--- 1er quartile (Q25)
%           |
%           |
%           |
%         -----         <--- Valeur Minimum
%         

%_________________________________________________________
% Auteur : C. Sorror 2013
%---------------------------------------------------------
[n, p] = size(Data);
Ptils  = [25, 50, 75];
Qtils  = prctile(Data,Ptils);
if (p==1) Qtils=Qtils'; end
minD  = min(Data);  maxD  = max(Data);
Qtils1=Qtils(1,:); Qtils2=Qtils(2,:); Qtils3=Qtils(3,:);
figure; hold on
if (~exist('OCTAVE_VERSION'))
   x=[1:4:4*p];
   line([x; x+2],      [Qtils1; Qtils1], 'linewidth',2.0,'color','b');
   line([x; x+2],      [Qtils2; Qtils2], 'linewidth',2.0,'color','r');
   line([x; x+2],      [Qtils3; Qtils3], 'linewidth',2.0,'color','b');
   line([x; x],        [Qtils1; Qtils3], 'linewidth',2.0,'color','b');
   line([x+2; x+2],    [Qtils1; Qtils3], 'linewidth',2.0,'color','b');
   line([x+1; x+1],    [minD;   Qtils1], 'linewidth',2.0,'color','b','linestyle','--');
   line([x+0.5; x+1.5],[minD;   minD  ], 'linewidth',2.0,'color','k');
   line([x+1; x+1],    [Qtils3; maxD  ], 'linewidth',2.0,'color','b','linestyle','--');
   line([x+0.5; x+1.5],[maxD;   maxD  ], 'linewidth',2.0,'color','k');
%
else %OCTAVE_VERSION, because Octave does not seem to got on well with the above vectorial version
   i = 1;
   for x=1:4:4*p
    line([x, x+2],      [Qtils(1,i), Qtils(1,i)], 'linewidth',2.0,'color','b');
    line([x, x+2],      [Qtils(2,i), Qtils(2,i)], 'linewidth',2.0,'color','r');
    line([x, x+2],      [Qtils(3,i), Qtils(3,i)], 'linewidth',2.0,'color','b');
    line([x, x],        [Qtils(1,i), Qtils(3,i)], 'linewidth',2.0,'color','b');
    line([x+2, x+2],    [Qtils(1,i), Qtils(3,i)], 'linewidth',2.0,'color','b');
    line([x+1, x+1],    [minD(i),    Qtils(1,i)], 'linewidth',2.0,'color','b','linestyle','--');
    line([x+0.5, x+1.5],[minD(i),    minD(i)   ], 'linewidth',2.0,'color','k');
    line([x+1, x+1],    [Qtils(3,i), maxD(i)   ], 'linewidth',2.0,'color','b','linestyle','--');
    line([x+0.5, x+1.5],[maxD(i),    maxD(i)   ], 'linewidth',2.0,'color','k');
    i = i+1;
  end
end
%
mminD = min(minD);  mmaxD = max(maxD);
dD = mmaxD - mminD;
axis([0, 4*p, mminD-0.05*dD, mmaxD+0.05*dD]);
set(gca,'xtick',[2:4:4*p],'xticklabel',[1:p]);
box on;
xlabel('Numro de colonne'); ylabel('Valeurs'); 
title('Boites  moustache');


%=========================================================
%
